FormulaException class

Small, dependency-free expression engine used by VisualPDF templates.

Supported operators: + - * /, comparisons, parentheses and the functions SUM, IF, ROUND and DATE_FORMAT.

Implemented types

Constructors

FormulaException(String message, [int? offset])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
offset int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited