VisualPdfStrings class

Small, dependency-free localization layer for the editor and runtime.

Constructors

VisualPdfStrings(String languageCode)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isGerman bool
no setter
languageCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
t(String de, String en) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) VisualPdfStrings