ReportPaperSize enum

ISO 216 paper sizes supported by VisualPDF.

Inheritance
Available extensions

Values

a5 → const ReportPaperSize
a4 → const ReportPaperSize
a3 → const ReportPaperSize
a2 → const ReportPaperSize

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String

Available on ReportPaperSize, provided by the ReportPaperSizeDimensions extension

Human-readable ISO paper label.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
portraitPoints → (double, double)

Available on ReportPaperSize, provided by the ReportPaperSizeDimensions extension

Portrait dimensions in PDF points.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ReportPaperSize>
A constant List of the values in this enum, in order of their declaration.