ReportTemplate class
A configurable ISO paper layout containing positioned report elements.
Constructors
-
ReportTemplate({String name = 'Neue Vorlage', ReportPaperSize paperSize = ReportPaperSize.a4, ReportOrientation orientation = ReportOrientation.portrait, double headerHeight = 72, String locale = 'de-DE', String currency = 'EUR', List<
ReportFont> ? fonts, List<ReportElement> ? elements, Map<String, dynamic> ? variables}) - Creates an empty or pre-populated report template.
-
ReportTemplate.fromJson(Map<
String, dynamic> json) -
Restores an unwrapped template from decoded JSON.
factory
- ReportTemplate.fromVps(String source)
-
Parses and validates a versioned VPS document.
factory
- ReportTemplate.parse(String source)
-
Parses an unwrapped template JSON document.
factory
Properties
- currency ↔ String
-
ISO-4217 currency used by currency columns and summaries.
getter/setter pair
-
elements
→ List<
ReportElement> -
final
-
fonts
→ List<
ReportFont> -
final
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerHeight ↔ double
-
getter/setter pair
- locale ↔ String
-
BCP-47 locale used for values and system dates in this report.
getter/setter pair
- name ↔ String
-
getter/setter pair
- orientation ↔ ReportOrientation
-
getter/setter pair
- pageHeight → double
-
Physical page height in PDF points after applying orientation.
no setter
- pageWidth → double
-
Physical page width in PDF points after applying orientation.
no setter
- paperSize ↔ ReportPaperSize
-
getter/setter pair
- pdfPageFormat → PdfPageFormat
-
PDF page format used by the renderer.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variables
→ Map<
String, dynamic> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pretty(
) → String - Returns the unwrapped template as indented JSON.
-
toJson(
) → Map< String, dynamic> - Serializes the unwrapped template model to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
-
toVps(
) → String - Returns a complete, versioned VPS document.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited