SummaryLine class

A calculated table-summary result returned by calculateSummary.

Constructors

SummaryLine(String label, double amount, {bool bold = false, ColumnFormat format = ColumnFormat.currency, String targetColumnField = ''})
Creates an immutable summary result.
const

Properties

amount double
final
bold bool
final
format ColumnFormat
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetColumnField String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited