AggregateRule class

Describes one calculated line beneath a table.

Constructors

AggregateRule({String label = 'Summe', AggregateFunction function = AggregateFunction.sum, String expression = 'total', bool bold = false, ColumnFormat format = ColumnFormat.currency, String targetColumnField = ''})
Creates an aggregate rule.
AggregateRule.fromJson(Map<String, dynamic> json)
Restores an aggregate rule from VPS-compatible JSON.
factory

Properties

bold bool
getter/setter pair
expression String
getter/setter pair
format ColumnFormat
getter/setter pair
function AggregateFunction
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
label String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetColumnField String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this rule to VPS-compatible JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited