ReportColumn class
Describes a column in a JSON-backed table element.
Constructors
- ReportColumn({required String title, required String field, double flex = 1, ColumnFormat format = ColumnFormat.text, bool alignRight = false})
- Creates a report column.
-
ReportColumn.fromJson(Map<
String, dynamic> json) -
Restores a report column from VPS-compatible JSON.
factory
Properties
- alignRight ↔ bool
-
getter/setter pair
- field ↔ String
-
getter/setter pair
- flex ↔ double
-
getter/setter pair
- format ↔ ColumnFormat
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this column to VPS-compatible JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited