ReportElement class
A positioned, printable element in a ReportTemplate.
Constructors
-
ReportElement({required String id, required ElementType type, double x = 50, double y = 50, double width = 180, double height = 40, String value = '', double fontSize = 12, bool bold = false, String textAlign = 'left', String fontFamily = 'Helvetica', int printColor = 0xff172033, String dataSource = 'items', List<
ReportColumn> ? columns, double rowHeight = 24, int headerColor = 0xff3156d3, int headerTextColor = 0xffffffff, int alternateRowColor = 0xfff3f5f9, bool showBorders = true, String imageBase64 = '', String imageName = '', String imageFit = 'contain', bool showSummary = true, bool showSubtotal = true, bool showTaxes = true, String amountExpression = 'total', double discountPercent = 0, String discountLabel = 'Rabatt', String subtotalLabel = 'Zwischensumme', String totalLabel = 'Gesamtbetrag', List<TaxRule> ? taxRules, List<AggregateRule> ? aggregateRules, String lineDirection = 'horizontal', double lineThickness = 1.5, String codeValue = '', String barcodeType = 'ean13', bool showCodeText = true, String band = 'body', String visibilityCondition = '', ElementPageVisibility pageVisibility = ElementPageVisibility.all, bool locked = false, bool keepTogether = false, bool flow = false, String section = 'body', String groupBy = '', String groupHeader = '{{group}}', bool showGroupHeader = true, ChartType chartType = ChartType.bar, String chartCategoryField = 'label', String chartValueExpression = 'value', bool chartShowLegend = true, bool chartShowLabels = true, List<int> ? chartColors}) - Creates a report element with type-specific styling and data settings.
-
ReportElement.fromJson(Map<
String, dynamic> json) -
Restores an element from VPS-compatible JSON.
factory
Properties
-
aggregateRules
→ List<
AggregateRule> -
final
- alternateRowColor ↔ int
-
getter/setter pair
- amountExpression ↔ String
-
getter/setter pair
- band ↔ String
-
getter/setter pair
- barcodeType ↔ String
-
getter/setter pair
- bold ↔ bool
-
getter/setter pair
- chartCategoryField ↔ String
-
getter/setter pair
-
chartColors
→ List<
int> -
final
- chartShowLabels ↔ bool
-
getter/setter pair
- chartShowLegend ↔ bool
-
getter/setter pair
- chartType ↔ ChartType
-
getter/setter pair
- chartValueExpression ↔ String
-
getter/setter pair
- codeValue ↔ String
-
getter/setter pair
-
columns
→ List<
ReportColumn> -
final
- dataSource ↔ String
-
getter/setter pair
- discountLabel ↔ String
-
getter/setter pair
- discountPercent ↔ double
-
getter/setter pair
- flow ↔ bool
-
getter/setter pair
- fontFamily ↔ String
-
getter/setter pair
- fontSize ↔ double
-
getter/setter pair
- groupBy ↔ String
-
getter/setter pair
-
getter/setter pair
- groupHeader ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerColor ↔ int
-
getter/setter pair
- headerTextColor ↔ int
-
getter/setter pair
- height ↔ double
-
getter/setter pair
-
getter/setter pair
- id ↔ String
-
getter/setter pair
- imageBase64 ↔ String
-
getter/setter pair
- imageFit ↔ String
-
getter/setter pair
- imageName ↔ String
-
getter/setter pair
- keepTogether ↔ bool
-
getter/setter pair
- lineDirection ↔ String
-
getter/setter pair
- lineThickness ↔ double
-
getter/setter pair
- locked ↔ bool
-
getter/setter pair
- pageVisibility ↔ ElementPageVisibility
-
getter/setter pair
- printColor ↔ int
-
getter/setter pair
- rowHeight ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- section ↔ String
-
getter/setter pair
- showBorders ↔ bool
-
getter/setter pair
- showCodeText ↔ bool
-
getter/setter pair
-
getter/setter pair
- showGroupHeader ↔ bool
-
getter/setter pair
- showSubtotal ↔ bool
-
getter/setter pair
- showSummary ↔ bool
-
getter/setter pair
- showTaxes ↔ bool
-
getter/setter pair
- subtotalLabel ↔ String
-
getter/setter pair
-
taxRules
→ List<
TaxRule> -
final
- textAlign ↔ String
-
getter/setter pair
- totalLabel ↔ String
-
getter/setter pair
- type ↔ ElementType
-
getter/setter pair
- value ↔ String
-
getter/setter pair
- visibilityCondition ↔ String
-
Optional expression such as
customer.country == "DE".getter/setter pair - width ↔ double
-
getter/setter pair
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this element to VPS-compatible JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited