ReportFont class
A TTF or OTF font embedded directly in a VPS template.
Constructors
- ReportFont({required String family, required String fileName, required String data})
-
ReportFont.fromJson(Map<
String, dynamic> json) -
factory
Properties
- data ↔ String
-
getter/setter pair
- family ↔ String
-
getter/setter pair
- fileName ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPdfCompatible → bool
-
Whether the font contains TrueType outlines supported by the PDF engine.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited