TaxRule class

Defines an optional tax line for a table summary.

Constructors

TaxRule({String label = 'MwSt. 19 %', double rate = 19, String filterField = '', String filterValue = ''})
Creates a tax rule.
TaxRule.fromJson(Map<String, dynamic> json)
Restores a tax rule from VPS-compatible JSON.
factory

Properties

filterField String
getter/setter pair
filterValue String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
label String
getter/setter pair
rate double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this rule to VPS-compatible JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited