VisualPdfRuntime class
Read-only report runner: it combines a VPS template with JSON data and exposes only preview, PDF export and printing.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- VisualPdfRuntime
Constructors
-
VisualPdfRuntime({Key? key, String? initialVps, String? initialJson, String? templatePath, String? dataPath, bool autoPrint = false, Locale uiLocale = const Locale('de'), ValueChanged<
Locale> ? onUiLocaleChanged}) -
Creates a read-only PDF preview and print workflow.
const
Properties
- autoPrint → bool
-
Whether to request the native print dialog after initial loading.
final
- dataPath → String?
-
Optional trusted desktop path to a JSON data file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialJson → String?
-
JSON report-data source loaded when the widget starts.
final
- initialVps → String?
-
VPS source loaded when the widget starts.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onUiLocaleChanged
→ ValueChanged<
Locale> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templatePath → String?
-
Optional trusted desktop path to a VPS file.
final
- uiLocale → Locale
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< VisualPdfRuntime> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited